Custom theme that can be applied to ggplot2 plots. Increases base font size, sets a white background, grey grid, and black border and text.
Examples
if (FALSE)
ggplot(mtcars, aes(factor(cyl), mpg)) + geom_boxplot() + tr_theme_min()
Custom theme that can be applied to ggplot2 plots. Increases base font size, sets a white background, grey grid, and black border and text.
if (FALSE)
ggplot(mtcars, aes(factor(cyl), mpg)) + geom_boxplot() + tr_theme_min()